import { TruContextFilter } from '../../../classes/tru-context-filter';
import { TruDesktopViewConfig } from '../classes/tru-desktop-view-config';
import { TruDataContext } from '../../../services/tru-data-context';
import * as i0 from "@angular/core";
export declare class TruDesktopService {
    /**
     * @tru.doc function
     * @name DesktopService.createDesktop
     * @module tru.desktop
     *
     * @description
     * Creates a new desktop instance.
     *
     * @returns {object} Desktop
     */
    createDesktop: () => Desktop;
    static ɵfac: i0.ɵɵFactoryDeclaration<TruDesktopService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<TruDesktopService>;
}
/**
 * @tru.desktop.doc class
 * @name DesktopService.Desktop
 * @module tru.desktop
 *
 * @description Desktop defines a logical desktop.  Any non-dom properties and elements needed by the desktop should
 * be defined in this class
 *
 */
export declare class Desktop {
    options: DesktopOptions;
    windowConfig: WindowConfig;
    viewConfig: TruDesktopViewConfig;
}
/**
 * @tru.desktop.doc class
 * @name DesktopService.DesktopOptions
 * @module tru.desktop
 *
 * @description Default DesktopOptions class.  DesktopOptions are defined by the application developer and overlaid
 * over this object.
 *
 */
export declare class DesktopOptions {
    allowDirtyClose: boolean;
    allowInvalidClose: boolean;
    cancelEditingOnNavigation: boolean;
    canCloseFn: undefined;
    canNavigateFn: undefined;
    displayViewportDimensions: boolean;
    enableAnimation: boolean;
    enableWindowCascading: boolean;
    logoUrl: undefined;
    menubarHeight: number;
    menubarConfig: undefined;
    showLaunchMenu: boolean;
}
/**
 * @tru.desktop.doc class
 * @name DesktopService.WindowConfig
 * @module tru.desktop
 *
 * @description
 * Default configuration object for a window. windowConfig properties can be defined by the application developer and overlaid
 * over this object.
 *
 */
export declare class WindowConfig {
    tableName: string;
    tablePluralName: string;
    tablePluralLabel: string;
    active: boolean;
    bottom: string;
    globals: undefined;
    height: string;
    isDirty: boolean;
    isInvalid: boolean;
    left: number;
    maximized: undefined;
    minHeight: string;
    minimized: boolean;
    minWidth: string;
    outOfBounds: boolean;
    savedPosition: {};
    right: string;
    scope: undefined;
    title: string;
    top: number;
    width: string;
    views: TruDesktopViewConfig[];
    zIndex: number;
    isReadOnly: boolean;
    unsubscribes: Array<any>;
    wasReadOnly: boolean;
    contextFilters: Array<TruContextFilter>;
    parentDataContext: TruDataContext | null;
    parentView: any | null;
    closed: () => void;
    destroy: () => void;
}
