import { OnInit } from '@angular/core';
import { TruTextManager } from '../../services/tru-text-manager';
import { TruUtil } from '../../services/tru-util';
import { TruDesktopEventHandler } from './services/tru-desktop-event-handler';
import { TruDesktopService, WindowConfig } from './services/tru-desktop-service';
import { TruWindowCloseEventArgs } from './services/tru-window-close-event-args';
import * as i0 from "@angular/core";
export declare class TruDesktop implements OnInit {
    private desktopService;
    private textManager;
    private truDesktopEventHandler;
    private util;
    options: any;
    private viewportComponent;
    constructor(desktopService: TruDesktopService, textManager: TruTextManager, truDesktopEventHandler: TruDesktopEventHandler, util: TruUtil);
    minimizeAll: boolean;
    desktop: any;
    minWindowCascadePosition: number;
    maxWindowCascadePosition: number;
    lastWindowCascadePosition: {
        top: number;
        left: number;
    };
    shiftPressed: boolean;
    altPressed: boolean;
    xPressed: boolean;
    logoUrl: null;
    /**
     * @tru.doc function
     * @name truDesktopComponent.getDesktop
     * @module tru.desktop
     *
     * @description
     * Return an object of desktop.
     *
     * @returns {object} desktop.
     */
    getDesktop: () => any;
    /**
     * @tru.doc function
     * @name truDesktopComponent.getOptions
     * @module tru.desktop
     *
     * @description
     * Return an object of desktop options.
     *
     * @returns {object} options.
     */
    getOptions: () => any;
    /**
     * @tru.doc function
     * @name truDesktopComponent.getWindows
     * @module tru.desktop
     *
     * @description
     * Return an array of windows.
     *
     * @returns {array} windows.
     */
    getWindows: () => any[];
    /**
     * @tru.doc function
     * @name truDesktopComponent.getNextMaxZIndex
     * @module tru.desktop
     *
     * @description
     * Iterates through all window objects in the windows array to find the max z-index
     * and increases the value found by 1.
     *
     * @returns {int}
     */
    getNextMaxZIndex: () => number;
    /**
     * @tru.doc function
     * @name truDesktopComponent.clearActive
     * @module tru.desktop
     *
     * @description
     * Iterates through all window objects in the windows
     * and sets the active property to false.
     *
     */
    clearActive: () => void;
    /**
     * @tru.doc function
     * @name truDesktopComponent.getActiveWindow
     * @module tru.desktop
     *
     * @description
     * Gets the active window.
     *
     * @returns {object} view object.
     */
    getActiveWindow: () => any;
    /**
     * @tru.doc function
     * @name truDesktopComponent.getActiveView
     * @module tru.desktop
     *
     * @description
     * Gets the active view.
     *
     * @returns {object} view object.
     */
    getActiveView: (wdw: any) => null;
    /**
     * @tru.doc function
     * @name truDesktopComponent.allWindowsAreMinimized
     * @module tru.desktop
     *
     * @description
     * Iterates through windows to determine if all are minimized.
     *
     */
    allWindowsAreMinimized: () => boolean;
    /**
     * @tru.doc function
     * @name truDesktopComponent.hideShowAll
     * @module tru.desktop
     *
     * @description
     * Hides/shows all windows
     *
     */
    hideShowAll: () => boolean;
    /**
     * @tru.doc function
     * @name truDesktopComponent.findWindowViewDirective
     * @module tru.desktop
     *
     * @description
     * Looks for previously open window with a view directive
     *
     */
    findWindowViewDirective: (windowViewDirective: any) => any;
    /**
     * @tru.doc function
     * @name truDesktopComponent.openWindow
     * @module tru.desktop
     *
     * @description
     * Displays a new window. All window properties defined by the application developer will be
     * overlaid here before displaying the window
     *
     */
    openWindow: (windowConfigOverlays: any, singleInstance: any) => WindowConfig;
    /**
     * @tru.doc function
     * @name truDesktopComponent.configureWindow
     * @module tru.desktop
     *
     * @description
     * Creates a new window instance.
     *
     */
    configureWindow: (windowConfigOverlays: any) => any;
    /**
     * @tru.doc function
     * @name truDesktopComponent.configureViews
     * @module tru.desktop
     *
     * @description
     * Creates one or more view instances
     *
     */
    configureViews: (windowConfigOverlays: any, configuredWindow: any) => Array<any>;
    /**
     * @tru.doc function
     * @name truDesktopComponent.closeWindow
     * @module tru.desktop
     *
     * @description
     * Remove a window {object} from the windows array.
     *
     * @returns {boolean} returns true if window was closed, false if not closed.
     */
    closeWindow: (wdw: any, windowCloseEventArgs?: TruWindowCloseEventArgs | null) => boolean;
    /**
     * @tru.doc function
     * @name truDesktopComponent.activateForemostWindow
     * @module tru.desktop
     *
     * @description
     * Set the foremost window to an active state
     *
     */
    activateForemostWindow: () => void;
    /**
     * @tru.doc function
     * @name truDesktopComponent.activateNextWindow
     * @module tru.desktop
     *
     * @description
     * Set the next window to an active state
     *
     */
    activateNextWindow: (activeWindowLocation: any) => void;
    /**
     * @tru.doc function
     * @name truDesktopComponent.activatePreviousWindow
     * @module tru.desktop
     *
     * @description
     * Set the previous window to an active state
     *
     */
    activatePreviousWindow: (activeWindowLocation: any) => void;
    /**
     * @tru.doc function
     * @name truDesktopComponent.minimize
     * @module tru.desktop
     *
     * @description
     * Visually removes window from the viewport.
     *
     */
    minimize: (window: any) => void;
    /**
     * @tru.doc function
     * @name truDesktopComponent.maximize
     * @module tru.desktop
     *
     * @description
     * Positions window such that it fills the whole viewport.
     *
     */
    maximize: (window: any) => void;
    /**
     * @tru.doc function
     * @name truDesktopComponent.maximizeLeft
     * @module tru.desktop
     *
     * @description
     * Positions window such that it fills the left portion viewport.
     *
     */
    maximizeLeft: (window: any) => void;
    /**
     * @tru.doc function
     * @name truDesktopComponent.maximizeRight
     * @module tru.desktop
     *
     * @description
     * Positions window such that it fills the right portion viewport.
     *
     */
    maximizeRight: (window: any) => void;
    /**
     * @tru.doc function
     * @name truDesktopComponent.recover
     * @module tru.desktop
     *
     * @description
     * Brings window back into view when it has escaped the viewport.
     *
     */
    recover: (window: any) => void;
    /**
     * @tru.doc function
     * @name truDesktopComponent.restore
     * @module tru.desktop
     *
     * @description
     *
     */
    restore: (wdw: any) => void;
    /**
     * @tru.doc function
     * @name truDesktopComponent.bringToFront
     * @module tru.desktop
     *
     * @description
     *
     */
    updateWindowState: (wdw: any) => void;
    /**
     * @tru.doc function
     * @name truDesktopComponent.restoreSavedPosition
     * @module tru.desktop
     *
     * @description
     * Set the windows last know position to the current position.
     *
     */
    restoreSavedPosition: (wdw: any) => void;
    /**
     * @tru.doc function
     * @name truDesktopComponent.savePosition
     * @module tru.desktop
     *
     * @description
     * Save the windows last know position.
     *
     */
    savePosition: (wdw: any) => void;
    /**
     * @tru.doc function
     * @name truDesktopComponent.closeWindow
     * @module tru.desktop
     *
     * @description
     * Moves a window to the next cascade position.
     *
     */
    cascadeWindow: (window: any) => void;
    /**
     * @tru.doc event
     * @module tru.desktop
     *
     * @description
     *
     */
    onKeyDown: (event: any) => void;
    onKeyUp: (event: any) => void;
    /**
     * @tru.doc function
     * @name truDesktopComponent.handleSelectAttempt
     * @module tru.desktop
     *
     * @description
     * Prevents the user from highlight desktop elements.
     *
     */
    handleSelectAttempt: (e: any) => boolean;
    windows: Array<any>;
    ngOnInit(): void;
    ngOnDestroy(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<TruDesktop, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<TruDesktop, "tru-desktop", never, { "options": { "alias": "options"; "required": false; }; }, {}, never, never, true, never>;
}
