import { AfterViewInit, ChangeDetectorRef, ElementRef, OnInit } from '@angular/core';
import { TruDataContext } from '../../../services/tru-data-context';
import { TruTextManager } from '../../../services/tru-text-manager';
import { TruUiNotification } from '../../../services/tru-ui-notification';
import { TruUtil } from '../../../services/tru-util';
import { TruWindowCloseEventArgs } from '../services/tru-window-close-event-args';
import { TruWindowEventHandler } from '../services/tru-window-event-handler';
import * as i0 from "@angular/core";
export declare class TruDesktopWindow implements OnInit, AfterViewInit {
    private dataContext;
    private uiNotification;
    private textManager;
    private windowEventHandler;
    private elementRef;
    private util;
    private cd;
    window: any;
    viewportCtrl: any;
    desktopCtrl: any;
    constructor(dataContext: TruDataContext, uiNotification: TruUiNotification, textManager: TruTextManager, windowEventHandler: TruWindowEventHandler, elementRef: ElementRef, util: TruUtil, cd: ChangeDetectorRef);
    x: number;
    y: number;
    lastX: number;
    lastY: number;
    startX: number;
    startY: number;
    titleBar: HTMLElement | null;
    canCloseFn: undefined;
    canNavigateFn: () => boolean;
    cancelEditingOnNavigation: boolean;
    viewportDimensions: any;
    showNavigation: boolean;
    hasChanges: boolean;
    private subs;
    private onHasChangedToken;
    mouseMove: (event: MouseEvent) => void;
    mouseUp: (event: MouseEvent) => void;
    /**
     * @tru.doc function
     * @name truDesktopWindowComponent.updateNavigationState
     * @module tru.desktop.window
     *
     * @description
     * Updates window navigation buttons based location of the active view in the views array.
     *
     */
    updateNavigationState: () => void;
    /**
     * @tru.doc function
     * @name truDesktopWindowComponent.isWindowInViewport
     * @module tru.desktop.window
     *
     * @description
     * Determines if the window is within the viewport boundaries.
     *
     */
    isWindowInViewport: () => void;
    /**
     * @tru.doc function
     * @name truDesktopWindowComponent.getWindow
     * @module tru.desktop.window
     *
     * @description
     * Gets the window object.
     *
     * @returns {object} window object.
     */
    getWindow: () => any;
    /**
     * @tru.doc function
     * @name truDesktopWindowComponent.setWindowTitle
     * @module tru.desktop.window
     *
     * @description
     * Sets the window title.
     *
     * @param {string} value to display in the window title bar.
     */
    setWindowTitle: (value: string) => void;
    getWindowTitle: () => any;
    isActive: () => boolean;
    /**
     * @tru.doc function
     * @name truDesktopWindowComponent.goToPreviousView
     * @module tru.desktop.window
     *
     * @description
     * Public method for navigating to the previous view.
     *
     */
    goToPreviousView: () => void;
    /**
     * @tru.doc function
     * @name truDesktopWindowComponent.viewIsEditing
     * @module tru.desktop.window
     *
     * @description
     * Checks whether view is editing.
     *
     * @returns {boolean}.
     */
    viewIsEditing: () => boolean;
    /**
     * @tru.doc function
     * @name truDesktopWindowComponent.canNavigate
     * @module tru.desktop.window
     *
     * @description
     * Checks whether navigation can occur..
     *
     * @returns {boolean}.
     */
    canNavigate: () => boolean;
    /**
     * @tru.doc function
     * @name truDesktopWindowComponent.removeForwardViews
     * @module tru.desktop.window
     *
     * @description
     * Removes all view(s) forward of the active view.
     *
     */
    removeForwardViews: () => void;
    /**
     * @tru.doc function
     * @name truDesktopWindowComponent.addView
     * @module tru.desktop.window
     *
     * @description
     * Removes all inactive view(s) following the active view and inserts a new view.
     *
     */
    addView: (viewConfig: any) => void;
    /**
     * @tru.doc function
     * @name truDesktopWindowComponent.getGlobals
     * @module tru.desktop.window
     *
     * @description
     * returns the global values.
     *
     */
    getGlobals: () => any;
    /**
     * @tru.doc function
     * @name truDesktopWindowComponent.firstView
     * @module tru.desktop.window
     *
     * @description
     *
     */
    firstView: () => void;
    /**
     * @tru.doc function
     * @name truDesktopWindowComponent.firstView
     * @module tru.desktop.window
     *
     * @description
     *
     */
    lastView: () => void;
    resizeEventHandler: () => void;
    /**
     * @tru.doc event
     * @module tru.desktop.window
     *
     * @description
     *
     */
    onWindowKeydown: (event: KeyboardEvent) => void;
    /**
     * @tru.doc watch
     * @module tru.desktop.window
     *
     * @description
     * Monitors the window's minimized state
     *
     */
    disablePrevious: boolean;
    disableNext: boolean;
    activate: () => void;
    minimize: () => void;
    maximize: () => void;
    close: (windowCloseEventArgs?: TruWindowCloseEventArgs | null) => void;
    windowTitleMouseDown: (event: MouseEvent) => void;
    previousView: () => void;
    nextView: () => void;
    save: () => void;
    revert: () => void;
    ngOnInit(): void;
    ngAfterViewInit(): void;
    ngOnDestroy(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<TruDesktopWindow, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<TruDesktopWindow, "tru-desktop-window", never, { "window": { "alias": "window"; "required": false; }; "viewportCtrl": { "alias": "viewportCtrl"; "required": false; }; "desktopCtrl": { "alias": "desktopCtrl"; "required": false; }; }, {}, never, never, true, never>;
}
