import { Entity, EntityChangedEventArgs, EntityType, ValidationError } from "breeze-client";
import { Observable, Subject } from 'rxjs';
import { TruDataChange } from '../classes/tru-data-change';
import { ITruAncestor } from '../interfaces/tru-ancestor';
import { TruAppEnvironment } from './tru-app-environment';
import { TruBreezeContext, TruBreezeContextFactory } from './tru-breeze-context-factory';
import { TruEntityAccessor } from './tru-entity-accessor';
import { TruGlobalDataContext } from './tru-global-data-context';
import { TruModelNavigationPropertiesLookup } from './tru-model-navigation-properties-lookup';
import { TruUiNotification } from './tru-ui-notification';
import * as i0 from "@angular/core";
export declare class TruDataContext {
    private breezeContextFactory;
    private modelNavigationPropertiesLookup;
    private globalDataContext;
    private appEnvironment;
    private entityAccessor;
    private uiNotification;
    private _propertyChanged$;
    private _dataChanged$;
    private _breezeContext;
    private _pendingDeleteEntities;
    private _pendingCascadeDeleteEntities;
    private updateDependants$;
    constructor(breezeContextFactory: TruBreezeContextFactory, modelNavigationPropertiesLookup: TruModelNavigationPropertiesLookup, globalDataContext: TruGlobalDataContext, appEnvironment: TruAppEnvironment, entityAccessor: TruEntityAccessor, uiNotification: TruUiNotification);
    onPropertyChanged(): Subject<any>;
    propertyChanged(changeArgs: EntityChangedEventArgs | null): void;
    onDataChanged(): Subject<TruDataChange>;
    dataChanged(change: TruDataChange): void;
    validationChangeDetection: Observable<unknown>;
    parseErrorMessages: (validationErrors: Array<ValidationError>) => string;
    getValidationErrorsForProperty: (entity: Entity, propertyName: string) => any;
    getValidationErrors: (entities?: Array<Entity> | null) => any;
    private modelPropertyChangeHandler;
    private modelPropertyOnSaveHandler;
    private modelPropertyOnAddHandler;
    private modelPropertyOnRejectHandler;
    /**
      * Handles breeze entity changed event.
      */
    private entityChangedHandler;
    private formatValidationErrors;
    private findCachedCascadeDeleteDescendants;
    private markCachedDescendantsForDelete;
    private markForDelete;
    get breezeContext(): TruBreezeContext;
    get entityManager(): import("breeze-client").EntityManager;
    get onHasChanged(): import("breeze-client").BreezeEvent<import("breeze-client").HasChangesChangedEventArgs>;
    hasChanges: (entityTypes?: Array<EntityType>) => Entity[];
    entityAccess: () => TruEntityAccessor;
    exportCahce: () => void;
    onUpdateDependants(): Subject<ITruAncestor>;
    updateDependants: (table: string, ancestorRef: string) => void;
    save: (entities?: Array<Entity> | null, deleteOperation?: boolean) => Promise<void>;
    saveWithoutNotification: () => Promise<void>;
    saveSettings: () => Promise<void>;
    revert: () => void;
    revertWithoutPrompt: () => void;
    delete: (entities: Array<Entity>, confirmMsg: string, onSuccess?: Function | undefined) => void;
    static ɵfac: i0.ɵɵFactoryDeclaration<TruDataContext, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<TruDataContext>;
}
