import { TruUtil } from './tru-util';
import * as i0 from "@angular/core";
export declare class TruTextManager {
    private util;
    readonly msgModifierKeyLabel: string;
    readonly msgConfirmExitWithChangesPending: string;
    readonly msgDeleteSuccessful: string;
    readonly msgSaveSuccessful: string;
    readonly msgNoChangesToSave: string;
    readonly msgSaveInProgress: string;
    readonly msgInvalidData: string;
    readonly msgDirtyPreventsReadOnly: string;
    readonly msgDirtyPreventsNavigate: string;
    readonly msgDirtyPreventsClose: string;
    readonly msgDirtyPreventsDeleteExistingRecord: string;
    readonly msgNoDeleteAccess: string;
    readonly msgCannotDeleteNewAndExistingRecords: string;
    readonly msgDeleteReferencingRecordsFirst: string;
    constructor(util: TruUtil);
    /**
    * If text.length exceeds length, then returns a string that is the first length chars
    * of text plus suffix.  Otherwise, returns text.
    * @param {string} text
    * @param {number} length
    * @param {string} suffix
    * @return {string}
    */
    private truncate;
    isMac: () => boolean;
    /**
     * Formats the text to use for the window title.
     * @param {string} text
     * @return {string} - Window title.
     */
    formatWindowTitle: (text: string) => string;
    /**
    * Returns a message indicating that an entity or entities were deleted in another view.
    * @param {string} entityTypeLabel - Description of the entity type.
    * @param [{string}] entityTypePluralLabel - Description of more than one of the entity type.
    * @param [{number}] count - Number of entities.
    */
    fmtEntityDeletedInOtherView: (entityTypeLabel: string, entityTypePluralLabel: string, count: number) => string;
    /**
     * Returns a message used to confirm deletion of an entity or entities.
     * @param {string} entityTypeLabel - Description of the entity type.
     * @param [{string}] entityTypePluralLabel - Description of more than one of the entity type.
     * @param [{number}] count - Number of entities.
     */
    fmtDeleteConfirmation: (entityTypeLabel: string, entityTypePluralLabel?: string | null, count?: number | null) => string;
    /**
     * Returns a message formatted from an error object.
     * @param {error|string} error
     * @returns {string}
     */
    fmtErrorToShow: (error: any) => string;
    /**
     * Returns a message formatted from an exception object.
     * @param {object} exception
     * @returns {string}
     */
    fmtExceptionToShow: (exception: any) => string;
    /**
     * Returns a message for a data error type.
     * @param {string} typeName
     * @returns {string}
     */
    fmtDataError: (typeName: string) => string;
    /**
      * Returns a message for an import error.
      * @param {string} typeName
      * @returns {string}
      */
    fmtImportError: (error: any) => string;
    /**
    * Serializes an object as URL parameters.  The object should be a base type or have
    * properties that are each base types.  Does not support a property with structure.
    * @param {Object} data
    * @returns {String}
    */
    formatAsUrlParameters: (data: any) => any;
    static ɵfac: i0.ɵɵFactoryDeclaration<TruTextManager, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<TruTextManager>;
}
